@@ -16,22 +16,26 @@
 #'
 #' @author maloneypatr, Irucka Embry
 #'
-#' @source Check if R package is installed then load library answered by
+#' @source
+#' \enumerate{
+#'    \item Check if R package is installed then load library answered by
 #'	maloneypatr is the source for the original function. See
-#'	\url{http://stackoverflow.com/questions/15155814/check-if-r-package-is-installed-then-load-library}.
+#'	\url{https://stackoverflow.com/questions/15155814/check-if-r-package-is-installed-then-load-library}.
+#'    \item Error Handling in R By Nina Zumel, October 9, 2012, R-Bloggers. See
+#'    \url{http://www.r-bloggers.com/error-handling-in-r/}.
+#' }
 #'
 #'
 #' @encoding UTF-8
 #'
-#' @seealso \code{\link{load_package}} to only load packages, \code{\link[needs]{needs}},
-#' \code{\link[easypackages]{install_packages}}, \code{\link[pacman]{p_load}}, \code{\link[utils]{installed.packages}},
+#' @seealso \code{\link{load_package}} to only load packages, \code{\link[utils]{installed.packages}},
 #' \code{\link[utils]{install.packages}}
 #'
 #'
 #'
 #' @examples
 #' \dontrun{
-#' library(install.load)
+#' library("install.load")
 #' # This will install, if not already installed, and load the package(s)
 #' install_load("chron")
 
@@ -40,6 +44,9 @@
 #'
 #'
 #' @import utils
+#' @import fastmatch
+#' @importFrom checkmate qtest
+#' @importFrom assertthat assert_that
 #'
 #' @export
 # Source begins
@@ -48,12 +55,15 @@ install_load <- function (package1, ...) {
   # convert arguments to vector
   packages <- c(package1, ...)
 
+assert_that(qtest(packages, "S"), msg = "One of the provided package(s) is(are) not a string. Please make sure that each packages is a string.")
+# only process with string values and provide a stop warning if not
+  
   # start loop to determine if each package is installed
   for (package in packages) {
 
     # if package is installed locally, load
-  if (package %in% rownames(installed.packages()))
-      do.call(library, list(package))
+  if (package %fin% rownames(installed.packages()))
+      try(do.call(library, list(package))) # Source 2
 
     # if package is not installed locally, download and then load
     else {
@@ -61,7 +71,7 @@ install_load <- function (package1, ...) {
       install.packages(package, repos =
         c("https://cloud.r-project.org", "http://owi.usgs.gov/R/"),
         dependencies = NA, type = getOption("pkgType"))
-      do.call(library, list(package))
+      try(do.call(library, list(package))) # Source 2
     }
   }
 }
